@@ -4,16 +4,23 @@ use Imager;
 use vars qw($VERSION @ISA);
 
 BEGIN {
-  $VERSION = "0.89";
+  $VERSION = "0.78";
 
-  require XSLoader;
-  XSLoader::load('Imager::File::JPEG', $VERSION);
+  eval {
+    require XSLoader;
+    XSLoader::load('Imager::File::JPEG', $VERSION);
+    1;
+  } or do {
+    require DynaLoader;
+    push @ISA, 'DynaLoader';
+    bootstrap Imager::File::JPEG $VERSION;
+  };
 }
 
 Imager->register_reader
   (
    type=>'jpeg',
-   single =>
+   single => 
    sub { 
      my ($im, $io, %hsh) = @_;
 
@@ -73,7 +80,7 @@ Imager's JPEG support is documented in L<Imager::Files>.
 
 =head1 AUTHOR
 
-Tony Cook <tonyc@cpan.org>
+Tony Cook <tony@imager.perl.org>
 
 =head1 SEE ALSO
 
