@@ -26,7 +26,7 @@ sub probe {
   ALTCHECK:
     my $index = 1;
     for my $alt (@{$req->{alternatives}}) {
-      $req->{altname} ||= "alt $index";
+      $req->{altname} = $alt->{altname} || "alt $index";
       $req->{verbose}
 	and print "$req->{name}: Trying alternative $index\n";
       my %work = %$req;
@@ -110,6 +110,9 @@ sub _probe_pkg {
       my $lflags = `pkg-config $pkg --libs`
 	and !$? or return;
 
+      my $defines = '';
+      $cflags =~ s/(-D\S+)/$defines .= " $1"; ''/ge;
+
       chomp $cflags;
       chomp $lflags;
       print "$req->{name}: Found via pkg-config $pkg\n";
@@ -117,6 +120,7 @@ sub _probe_pkg {
 	{
 	 INC => $cflags,
 	 LIBS => $lflags,
+	 DEFINE => $defines,
 	};
     }
   }
@@ -169,7 +173,7 @@ sub _probe_check {
   }
 
   my $alt = "";
-  if ($req->{alternatives}) {
+  if ($req->{altname}) {
     $alt = " $req->{altname}:";
   }
   print "$req->{name}:$alt includes ", $found_incpath ? "" : "not ",
@@ -186,13 +190,14 @@ sub _probe_check {
     push @libs, "-l$libbase";
   }
   else {
-    die "$req->{name}: inccheck but no libbase or libopts";
+    die "$req->{altname}: inccheck but no libbase or libopts";
   }
 
   return
     {
      INC => "-I$found_incpath",
      LIBS => "@libs",
+     DEFINE => "",
     };
 }
 
@@ -217,6 +222,7 @@ sub _probe_fake {
       {
        INC => "",
        LIBS => $lopts,
+       DEFINE => "",
       };
   }
   else {
@@ -395,6 +401,10 @@ C<INC> - C<-I> and other C options
 
 C<LIBS> - C<-L>, C<-l> and other link-time options
 
+=item *
+
+C<DEFINE> - C<-D> options, if any.
+
 =back
 
 The possible values for the hash supplied to the probe() method are:
